@@ -23,6 +23,7 @@ import logging
 import os
 import os.path
 import tarfile
+from getpass import getpass
 
 import click
 from rich import print
@@ -114,6 +115,29 @@ def get(_: Info, object_type: str, ref: str, url: str, token: str):
     KodexaPlatform.get(object_type, ref)
 
 
+@cli.command()
+@pass_info
+@click.option('--python/--no-python', default=False, help='Print out the header for a Python file')
+def platform(_: Info, python: bool):
+    """Get details of the instance of Kodexa you are using"""
+
+    platform_url = KodexaPlatform.get_url()
+
+    if platform_url is not None:
+        print(f"Kodexa URL: {KodexaPlatform.get_url()}")
+        print(f"Access Token: {KodexaPlatform.get_access_token()}")
+        kodexa_version = KodexaPlatform.get_server_info()
+        print(f"Version: {kodexa_version['version']}")
+        print(f"Release: {kodexa_version['release']}")
+        if python:
+            print("\nPython example:\n\n")
+            print(f"from kodexa import *")
+            print(f"KodexaPlatform.set_url('{KodexaPlatform.get_url()}')")
+            print(f"KodexaPlatform.set_access_token('{KodexaPlatform.get_access_token()}')")
+    else:
+        print("Kodexa is not logged in")
+
+
 @cli.command()
 @click.argument('object_type')
 @click.argument('ref')
@@ -137,6 +161,23 @@ def metadata(_: Info, path: str):
     print(f"Metadata loaded")
 
 
+@cli.command()
+@pass_info
+def login(_: Info):
+    """Login and store your PAT"""
+    try:
+        kodexa_url = input("Enter the Kodexa URL (https://platform.kodexa.com): ")
+        if kodexa_url == "":
+            print("Using default as https://platform.kodexa.com")
+            kodexa_url = "https://platform.kodexa.com"
+        username = input("Enter your email: ")
+        password = getpass("Enter your password: ")
+    except Exception as error:
+        print('ERROR', error)
+    else:
+        KodexaPlatform.login(kodexa_url, username, password)
+
+
 @cli.command()
 @click.option('--path', default=os.getcwd(), help='Path to folder container kodexa.yml')
 @pass_info
@@ -159,7 +200,7 @@ def document(_: Info, path: str):
 @click.option('--url', default='http://www.example.com/', help='The base URL for the site links')
 @pass_info
 def package(_: Info, path: str, output: str, version: str, site: bool, sitedir: str, url: str):
-    """Load metadata"""
+    """Package the extension for Kodexa"""
     metadata_obj = ExtensionHelper.load_metadata(path)
     print("Preparing to pack")
     try:
